@@ -4,48 +4,46 @@ package runtime
 
 import (
 	"os"
-	"os/exec"
 	"strconv"
 	"strings"
 	"time"
 
-	"github.com/shirou/gopsutil/v3/host"
-	mem "github.com/shirou/gopsutil/v3/mem"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
+	"github.com/shirou/gopsutil/v4/host"
+	mem "github.com/shirou/gopsutil/v4/mem"
 	terminal "github.com/wayneashleyberry/terminal-dimensions"
 	"golang.org/x/sys/unix"
 )
 
 func (term *Terminal) Root() bool {
-	defer term.Trace(time.Now())
+	defer log.Trace(time.Now())
 	return os.Geteuid() == 0
 }
 
-func (term *Terminal) Home() string {
-	return os.Getenv("HOME")
-}
-
 func (term *Terminal) QueryWindowTitles(_, _ string) (string, error) {
 	return "", &NotImplemented{}
 }
 
 func (term *Terminal) IsWsl() bool {
-	defer term.Trace(time.Now())
+	defer log.Trace(time.Now())
 	const key = "is_wsl"
-	if val, found := term.Cache().Get(key); found {
-		term.Debug(val)
-		return val == "true"
+	if val, found := cache.Get[bool](cache.Device, key); found {
+		return val
 	}
+
 	var val bool
 	defer func() {
-		term.Cache().Set(key, strconv.FormatBool(val), -1)
+		cache.Set(cache.Device, key, val, cache.INFINITE)
 	}()
+
 	val = term.HasCommand("wslpath")
-	term.Debug(strconv.FormatBool(val))
+
 	return val
 }
 
 func (term *Terminal) IsWsl2() bool {
-	defer term.Trace(time.Now())
+	defer log.Trace(time.Now())
 	if !term.IsWsl() {
 		return false
 	}
@@ -54,21 +52,21 @@ func (term *Terminal) IsWsl2() bool {
 }
 
 func (term *Terminal) IsCygwin() bool {
-	defer term.Trace(time.Now())
+	defer log.Trace(time.Now())
 	return false
 }
 
 func (term *Terminal) TerminalWidth() (int, error) {
-	defer term.Trace(time.Now())
+	defer log.Trace(time.Now())
 
 	if term.CmdFlags.TerminalWidth > 0 {
-		term.DebugF("terminal width: %d", term.CmdFlags.TerminalWidth)
+		log.Debugf("terminal width: %d", term.CmdFlags.TerminalWidth)
 		return term.CmdFlags.TerminalWidth, nil
 	}
 
 	width, err := terminal.Width()
 	if err != nil {
-		term.Error(err)
+		log.Error(err)
 	}
 
 	// fetch width from the environment variable
@@ -76,31 +74,41 @@ func (term *Terminal) TerminalWidth() (int, error) {
 	if width == 0 {
 		i, err := strconv.Atoi(term.Getenv("COLUMNS"))
 		if err != nil {
-			term.Error(err)
+			log.Error(err)
 		}
 		width = uint(i)
 	}
 
 	term.CmdFlags.TerminalWidth = int(width)
-	term.DebugF("terminal width: %d", term.CmdFlags.TerminalWidth)
+	log.Debugf("terminal width: %d", term.CmdFlags.TerminalWidth)
+
+	// Claude CLI has a 2 character padding on both sides
+	if term.CmdFlags.Shell == "claude" {
+		log.Debug("adjusting terminal width for Claude CLI")
+		term.CmdFlags.TerminalWidth -= 4
+	}
+
 	return term.CmdFlags.TerminalWidth, err
 }
 
 func (term *Terminal) Platform() string {
 	const key = "environment_platform"
-	if val, found := term.Cache().Get(key); found {
-		term.Debug(val)
+	if val, found := cache.Get[string](cache.Device, key); found {
 		return val
 	}
+
 	var platform string
 	defer func() {
-		term.Cache().Set(key, platform, -1)
+		cache.Set(cache.Device, key, platform, cache.INFINITE)
 	}()
+
 	if wsl := term.Getenv("WSL_DISTRO_NAME"); len(wsl) != 0 {
-		platform = strings.Split(strings.ToLower(wsl), "-")[0]
-		term.Debug(platform)
+		platform, _, _ = strings.Cut(wsl, "-")
+		platform = strings.ToLower(platform)
+		log.Debug(platform)
 		return platform
 	}
+
 	platform, _, _, _ = host.PlatformInformation()
 	if platform == "arch" {
 		// validate for Manjaro
@@ -109,7 +117,8 @@ func (term *Terminal) Platform() string {
 			platform = "manjaro"
 		}
 	}
-	term.Debug(platform)
+
+	log.Debug(platform)
 	return platform
 }
 
@@ -125,28 +134,24 @@ func (term *Terminal) InWSLSharedDrive() bool {
 	return !strings.HasPrefix(windowsPath, `//wsl.localhost/`) && !strings.HasPrefix(windowsPath, `//wsl$/`)
 }
 
-func (term *Terminal) ConvertToWindowsPath(path string) string {
-	windowsPath, err := term.RunCommand("wslpath", "-m", path)
+func (term *Terminal) ConvertToWindowsPath(input string) string {
+	windowsPath, err := term.RunCommand("wslpath", "-m", input)
 	if err == nil {
 		return windowsPath
 	}
-	return path
+	return input
 }
 
-func (term *Terminal) ConvertToLinuxPath(path string) string {
-	if linuxPath, err := term.RunCommand("wslpath", "-u", path); err == nil {
+func (term *Terminal) ConvertToLinuxPath(input string) string {
+	if linuxPath, err := term.RunCommand("wslpath", "-u", input); err == nil {
 		return linuxPath
 	}
-	return path
+	return input
 }
 
-func (term *Terminal) LookPath(command string) (string, error) {
-	return exec.LookPath(command)
-}
-
-func (term *Terminal) DirIsWritable(path string) bool {
-	defer term.Trace(time.Now(), path)
-	return unix.Access(path, unix.W_OK) == nil
+func (term *Terminal) DirIsWritable(input string) bool {
+	defer log.Trace(time.Now(), input)
+	return unix.Access(input, unix.W_OK) == nil
 }
 
 func (term *Terminal) Connection(_ ConnectionType) (*Connection, error) {
@@ -162,17 +167,27 @@ func (term *Terminal) Memory() (*Memory, error) {
 	m := &Memory{}
 	memStat, err := mem.VirtualMemory()
 	if err != nil {
-		term.Error(err)
+		log.Error(err)
 		return nil, err
 	}
+
 	m.PhysicalTotalMemory = memStat.Total
 	m.PhysicalAvailableMemory = memStat.Available
 	m.PhysicalFreeMemory = memStat.Free
-	m.PhysicalPercentUsed = memStat.UsedPercent
+
+	if memStat.Total > 0 {
+		used := float64(memStat.Total) - float64(memStat.Available)
+		if used < 0 {
+			used = 0
+		}
+		m.PhysicalPercentUsed = used / float64(memStat.Total) * 100
+	}
+
 	swapStat, err := mem.SwapMemory()
 	if err != nil {
-		term.Error(err)
+		log.Error(err)
 	}
+
 	m.SwapTotalMemory = swapStat.Total
 	m.SwapFreeMemory = swapStat.Free
 	m.SwapPercentUsed = swapStat.UsedPercent
