@@ -53,37 +53,38 @@ func (oi *Os) Enabled() bool {
 
 func (oi *Os) getDistroIcon(distro string) string {
 	iconMap := map[string]string{
-		"alma":                "\uF31D",
-		"almalinux":           "\uF31D",
-		"almalinux9":          "\uF31D",
-		"alpine":              "\uF300",
+		"alma":                "\uf31d",
+		"almalinux":           "\uf31d",
+		"almalinux9":          "\uf31d",
+		"alpine":              "\uf300",
 		"android":             "\ue70e",
-		"aosc":                "\uF301",
-		"arch":                "\uF303",
-		"centos":              "\uF304",
-		"coreos":              "\uF305",
-		"debian":              "\uF306",
-		"deepin":              "\uF321",
-		"devuan":              "\uF307",
-		"elementary":          "\uF309",
-		"endeavouros":         "\uF322",
-		"fedora":              "\uF30a",
-		"freebsd":             "\U000f08e0",
-		"gentoo":              "\uF30d",
+		"aosc":                "\uf301",
+		"arch":                "\uf303",
+		"centos":              "\uf304",
+		"coreos":              "\uf305",
+		"debian":              "\uf306",
+		"deepin":              "\uf321",
+		"devuan":              "\uf307",
+		"elementary":          "\uf309",
+		"endeavouros":         "\uf322",
+		"fedora":              "\uf30a",
+		"freebsd":             "\u000f08e0",
+		"gentoo":              "\uf30d",
 		"kali":                "\uf327",
-		"mageia":              "\uF310",
-		"manjaro":             "\uF312",
-		"mint":                "\U000f08ed",
-		"nixos":               "\uF313",
-		"opensuse":            "\uF314",
-		"opensuse-tumbleweed": "\uF314",
-		"raspbian":            "\uF315",
-		"redhat":              "\uF316",
-		"rocky":               "\uF32B",
-		"sabayon":             "\uF317",
-		"slackware":           "\uF319",
-		"ubuntu":              "\uF31b",
+		"mageia":              "\uf310",
+		"manjaro":             "\uf312",
+		"mint":                "\u000f08ed",
 		"neon":                "\uf331",
+		"nixos":               "\uf313",
+		"opensuse":            "\uf314",
+		"opensuse-tumbleweed": "\uf314",
+		"raspbian":            "\uf315",
+		"redhat":              "\uf316",
+		"rocky":               "\uf32b",
+		"sabayon":             "\uf317",
+		"slackware":           "\uf319",
+		"ubuntu":              "\uf31b",
+		"void":                "\uf32e",
 	}
 
 	if icon, ok := iconMap[distro]; ok {
